"use strict";
exports.__esModule = true;
var Function_1 = require("../src/Function");
var assert = require("assert");
describe("function composition", function () {
    it("Function0 tests", function () {
        var two = Function_1.Function0.of(function () { return 2; });
        assert.equal(4, two.andThen(function (x) { return x * 2; })());
        assert.equal(5, Function_1.Function0.constant(5)());
    });
    it("Function1 tests", function () {
        var add1 = Function_1.Function1.of(function (x) { return x + 1; });
        assert.equal(9, add1.compose(function (x) { return x * 2; })(4));
        assert.equal(10, add1.andThen(function (x) { return x * 2; })(4));
        assert.equal(5, Function_1.Function1.id()(5));
        assert.equal(5, Function_1.Function1.constant(5)(12));
    });
    it("Function2 tests", function () {
        var sumPlus1 = Function_1.Function2.of(function (x, y) { return x + y + 1; });
        assert.equal(16, sumPlus1.andThen(function (x) { return x * 2; })(4, 3));
        assert.equal(8, sumPlus1.curried()(4)(3));
        assert.equal(8, sumPlus1.tupled()([4, 3]));
        assert.equal(8, sumPlus1.flipped()(4, 3));
        assert.equal(5, Function_1.Function2.constant(5)(12, 32));
        assert.equal(8, sumPlus1.apply1(4)(3));
    });
    it("Function3 tests", function () {
        var sumPlus1 = Function_1.Function3.of(function (x, y, z) { return x + y + z + 1; });
        assert.equal(20, sumPlus1.andThen(function (x) { return x * 2; })(4, 3, 2));
        assert.equal(10, sumPlus1.curried()(4)(3)(2));
        assert.equal(10, sumPlus1.tupled()([4, 3, 2]));
        assert.equal(10, sumPlus1.flipped()(4, 3, 2));
        assert.equal(5, Function_1.Function3.constant(5)(12, 32, 45));
        assert.equal(10, sumPlus1.apply1(4)(3, 2));
        assert.equal(10, sumPlus1.apply2(4, 3)(2));
    });
    it("Function4 tests", function () {
        var sumPlus1 = Function_1.Function4.of(function (x, y, z, a) { return x + y + z + a + 1; });
        assert.equal(22, sumPlus1.andThen(function (x) { return x * 2; })(4, 3, 2, 1));
        assert.equal(11, sumPlus1.curried()(4)(3)(2)(1));
        assert.equal(11, sumPlus1.tupled()([4, 3, 2, 1]));
        assert.equal(11, sumPlus1.flipped()(4, 3, 2, 1));
        assert.equal(5, Function_1.Function4.constant(5)(12, 32, 45, 34));
        assert.equal(11, sumPlus1.apply1(4)(3, 2, 1));
        assert.equal(11, sumPlus1.apply2(4, 3)(2, 1));
        assert.equal(11, sumPlus1.apply3(4, 3, 2)(1));
    });
    it("Function5 tests", function () {
        var sumPlus1 = Function_1.Function5.of(function (x, y, z, a, b) { return x + y + z + a + b + 1; });
        assert.equal(22, sumPlus1.andThen(function (x) { return x * 2; })(4, 3, 2, 1, 0));
        assert.equal(11, sumPlus1.curried()(4)(3)(2)(1)(0));
        assert.equal(11, sumPlus1.tupled()([4, 3, 2, 1, 0]));
        assert.equal(11, sumPlus1.flipped()(4, 3, 2, 1, 0));
        assert.equal(5, Function_1.Function5.constant(5)(12, 32, 45, 34, 23));
        assert.equal(11, sumPlus1.apply1(4)(3, 2, 1, 0));
        assert.equal(11, sumPlus1.apply2(4, 3)(2, 1, 0));
        assert.equal(11, sumPlus1.apply3(4, 3, 2)(1, 0));
        assert.equal(11, sumPlus1.apply4(4, 3, 2, 1)(0));
    });
});
//# sourceMappingURL=Function.js.map