"use strict";
exports.__esModule = true;
var Vector_1 = require("../src/Vector");
var Option_1 = require("../src/Option");
var Comparison_1 = require("../src/Comparison");
var assert = require("assert");
function myEq(a, b) {
    if (a === null && b === null) {
        return true;
    }
    if ((a === null) !== (b === null)) {
        return false;
    }
    if (a === undefined && b === undefined) {
        return true;
    }
    if ((a === undefined) !== (b === undefined)) {
        return false;
    }
    if (a.isSome && b.isSome &&
        a.isSome() && b.isSome()) {
        // workaround for Option<array> equality
        // useful in HashMap tests
        return myEq(a.getOrThrow(), b.getOrThrow());
    }
    if (a.toArray) {
        // workaround for the zip test Vector.of([1,"a"]) equality
        // real Vector returns false, compilation error otherwise
        return myEq(a.toArray(), b.toArray());
    }
    if (a.equals) {
        return a.equals(b);
    }
    if (Array.isArray(a)) {
        if (a.length !== b.length) {
            return false;
        }
        for (var i = 0; i < a.length; i++) {
            if (!myEq(a[i], b[i])) {
                return false;
            }
        }
        return true;
    }
    return JSON.stringify(a) === JSON.stringify(b);
}
// adding date support to myEq above isn't enough because I have Option<Date>
// in one of the tests...
Date.prototype.equals = function (other) { return this.getTime() === other.getTime(); };
var randomValues = [0.49884723907769635, 0.3226548779864311];
var randomIndex = 0;
var origMathRandom = Math.random;
var mockMathRandom = function () { return randomValues[(randomIndex++) % randomValues.length]; };
function resetMathRandom() {
    randomIndex = 0;
    Math.random = mockMathRandom;
}
describe("Comparison.ts docstrings", function () {
    it("instanceOf", function () {
        resetMathRandom();
        var xvar = Vector_1.Vector.of("bad", new Date('04 Dec 1995 00:12:00 GMT')).filter(Comparison_1.instanceOf(Date));
        assert.ok(myEq(Vector_1.Vector.of(new Date('04 Dec 1995 00:12:00 GMT')), xvar), Vector_1.Vector.of(new Date('04 Dec 1995 00:12:00 GMT')) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Comparison.ts docstrings", function () {
    it("instanceOf", function () {
        resetMathRandom();
        var xvar = Option_1.Option.of("test").filter(Comparison_1.instanceOf(Date));
        assert.ok(myEq(Option_1.Option.none(), xvar), Option_1.Option.none() + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Comparison.ts docstrings", function () {
    it("instanceOf", function () {
        resetMathRandom();
        var xvar = Option_1.Option.of(new Date('04 Dec 1995 00:12:00 GMT')).filter(Comparison_1.instanceOf(Date));
        assert.ok(myEq(Option_1.Option.of(new Date('04 Dec 1995 00:12:00 GMT')), xvar), Option_1.Option.of(new Date('04 Dec 1995 00:12:00 GMT')) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Comparison.ts docstrings", function () {
    it("typeOf", function () {
        resetMathRandom();
        var xvar = Vector_1.Vector.of(1, "a", 2, 3, "b").filter(Comparison_1.typeOf("number"));
        assert.ok(myEq(Vector_1.Vector.of(1, 2, 3), xvar), Vector_1.Vector.of(1, 2, 3) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Comparison.ts docstrings", function () {
    it("typeOf", function () {
        resetMathRandom();
        var xvar = Option_1.Option.of(1).filter(Comparison_1.typeOf("string"));
        assert.ok(myEq(Option_1.Option.none(), xvar), Option_1.Option.none() + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Comparison.ts docstrings", function () {
    it("typeOf", function () {
        resetMathRandom();
        var xvar = Option_1.Option.of("str").filter(Comparison_1.typeOf("string"));
        assert.ok(myEq(Option_1.Option.of("str"), xvar), Option_1.Option.of("str") + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
//# sourceMappingURL=apidoc-Comparison.js.map