"use strict";
exports.__esModule = true;
var Vector_1 = require("../src/Vector");
var Either_1 = require("../src/Either");
var assert = require("assert");
function myEq(a, b) {
    if (a === null && b === null) {
        return true;
    }
    if ((a === null) !== (b === null)) {
        return false;
    }
    if (a === undefined && b === undefined) {
        return true;
    }
    if ((a === undefined) !== (b === undefined)) {
        return false;
    }
    if (a.isSome && b.isSome &&
        a.isSome() && b.isSome()) {
        // workaround for Option<array> equality
        // useful in HashMap tests
        return myEq(a.getOrThrow(), b.getOrThrow());
    }
    if (a.toArray) {
        // workaround for the zip test Vector.of([1,"a"]) equality
        // real Vector returns false, compilation error otherwise
        return myEq(a.toArray(), b.toArray());
    }
    if (a.equals) {
        return a.equals(b);
    }
    if (Array.isArray(a)) {
        if (a.length !== b.length) {
            return false;
        }
        for (var i = 0; i < a.length; i++) {
            if (!myEq(a[i], b[i])) {
                return false;
            }
        }
        return true;
    }
    return JSON.stringify(a) === JSON.stringify(b);
}
// adding date support to myEq above isn't enough because I have Option<Date>
// in one of the tests...
Date.prototype.equals = function (other) { return this.getTime() === other.getTime(); };
var randomValues = [0.49884723907769635, 0.3226548779864311];
var randomIndex = 0;
var origMathRandom = Math.random;
var mockMathRandom = function () { return randomValues[(randomIndex++) % randomValues.length]; };
function resetMathRandom() {
    randomIndex = 0;
    Math.random = mockMathRandom;
}
describe("Either.ts docstrings", function () {
    // no result to compare the output to, just make sure this compiles
    Either_1.Either.right(5);
    Either_1.Either.left(2);
    Either_1.Either.right(5).map(function (x) { return x * 2; });
});
describe("Either.ts docstrings", function () {
    it("isLeft", function () {
        resetMathRandom();
        var xvar = Vector_1.Vector.of(Either_1.Either.right(2), Either_1.Either.left(1))
            .filter(Either_1.Either.isLeft)
            .map(function (o) { return o.getLeft(); });
        assert.ok(myEq(Vector_1.Vector.of(1), xvar), Vector_1.Vector.of(1) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Either.ts docstrings", function () {
    it("isRight", function () {
        resetMathRandom();
        var xvar = Vector_1.Vector.of(Either_1.Either.right(2), Either_1.Either.left(1))
            .filter(Either_1.Either.isRight)
            .map(function (o) { return o.get(); });
        assert.ok(myEq(Vector_1.Vector.of(2), xvar), Vector_1.Vector.of(2) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Either.ts docstrings", function () {
    it("sequence", function () {
        resetMathRandom();
        var xvar = Either_1.Either.sequence(Vector_1.Vector.of(Either_1.Either.right(1), Either_1.Either.right(2)));
        ;
        assert.ok(myEq(Either_1.Either.right(Vector_1.Vector.of(1, 2)), xvar), Either_1.Either.right(Vector_1.Vector.of(1, 2)) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Either.ts docstrings", function () {
    it("sequence", function () {
        resetMathRandom();
        var xvar = Either_1.Either.sequence(Vector_1.Vector.of(Either_1.Either.right(1), Either_1.Either.left(2), Either_1.Either.left(3)));
        ;
        assert.ok(myEq(Either_1.Either.left(2), xvar), Either_1.Either.left(2) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Either.ts docstrings", function () {
    it("traverse", function () {
        resetMathRandom();
        var getUserById = function (x) { return x > 0 ?
            Either_1.Either.right("user" + x.toString()) : Either_1.Either.left("invalid id!"); };
        var xvar = Either_1.Either.traverse([4, 3, 2], getUserById);
        ;
        assert.ok(myEq(Either_1.Either.right(Vector_1.Vector.of("user4", "user3", "user2")), xvar), Either_1.Either.right(Vector_1.Vector.of("user4", "user3", "user2")) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Either.ts docstrings", function () {
    it("traverse", function () {
        resetMathRandom();
        var getUserById = function (x) { return x > 0 ?
            Either_1.Either.right("user" + x.toString()) : Either_1.Either.left("invalid id!"); };
        var xvar = Either_1.Either.traverse([4, -3, 2], getUserById);
        ;
        assert.ok(myEq(Either_1.Either.left("invalid id!"), xvar), Either_1.Either.left("invalid id!") + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Either.ts docstrings", function () {
    it("sequenceAcc", function () {
        resetMathRandom();
        var xvar = Either_1.Either.sequenceAcc(Vector_1.Vector.of(Either_1.Either.right(1), Either_1.Either.right(2)));
        ;
        assert.ok(myEq(Either_1.Either.right(Vector_1.Vector.of(1, 2)), xvar), Either_1.Either.right(Vector_1.Vector.of(1, 2)) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Either.ts docstrings", function () {
    it("sequenceAcc", function () {
        resetMathRandom();
        var xvar = Either_1.Either.sequenceAcc(Vector_1.Vector.of(Either_1.Either.right(1), Either_1.Either.left(2), Either_1.Either.left(3)));
        ;
        assert.ok(myEq(Either_1.Either.left(Vector_1.Vector.of(2, 3)), xvar), Either_1.Either.left(Vector_1.Vector.of(2, 3)) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Either.ts docstrings", function () {
    it("liftA2", function () {
        resetMathRandom();
        var lifted = Either_1.Either.liftA2(function (x, y) { return x + y; }, {});
        var xvar = lifted(Either_1.Either.right(5), Either_1.Either.right(6));
        ;
        assert.ok(myEq(Either_1.Either.right(11), xvar), Either_1.Either.right(11) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Either.ts docstrings", function () {
    it("liftA2", function () {
        resetMathRandom();
        var lifted = Either_1.Either.liftA2(function (x, y) { return x + y; }, {});
        var xvar = lifted(Either_1.Either.right(5), Either_1.Either.left("bad"));
        ;
        assert.ok(myEq(Either_1.Either.left("bad"), xvar), Either_1.Either.left("bad") + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Either.ts docstrings", function () {
    it("liftAp", function () {
        resetMathRandom();
        var fn = function (x) { return x.a + x.b + x.c; };
        var lifted = Either_1.Either.liftAp(fn, {});
        var xvar = lifted({
            a: Either_1.Either.right(5),
            b: Either_1.Either.right(6),
            c: Either_1.Either.right(3)
        });
        ;
        assert.ok(myEq(Either_1.Either.right(14), xvar), Either_1.Either.right(14) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Either.ts docstrings", function () {
    it("liftAp", function () {
        resetMathRandom();
        var lifted = Either_1.Either.liftAp(function (x) { return x.a + x.b; });
        var xvar = lifted({
            a: Either_1.Either.right(5),
            b: Either_1.Either.left(2)
        });
        ;
        assert.ok(myEq(Either_1.Either.left(2), xvar), Either_1.Either.left(2) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Either.ts docstrings", function () {
    it("liftApAcc", function () {
        resetMathRandom();
        var fn = function (x) { return x.a + x.b + x.c; };
        var lifted = Either_1.Either.liftApAcc(fn, {});
        var xvar = lifted({
            a: Either_1.Either.right(5),
            b: Either_1.Either.right(6),
            c: Either_1.Either.right(3)
        });
        ;
        assert.ok(myEq(Either_1.Either.right(14), xvar), Either_1.Either.right(14) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Either.ts docstrings", function () {
    it("liftApAcc", function () {
        resetMathRandom();
        var fn = function (x) { return x.a + x.b + x.c; };
        var lifted = Either_1.Either.liftApAcc(fn, {});
        var xvar = lifted({
            a: Either_1.Either.right(5),
            b: Either_1.Either.left(2),
            c: Either_1.Either.left(6)
        });
        ;
        assert.ok(myEq(Either_1.Either.left(Vector_1.Vector.of(2, 6)), xvar), Either_1.Either.left(Vector_1.Vector.of(2, 6)) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Either.ts docstrings", function () {
    it("lift", function () {
        resetMathRandom();
        var add = Either_1.Either.lift(function (x, y) { return x + y; }, {});
        var xvar = add(1, 2);
        ;
        assert.ok(myEq(Either_1.Either.right(3), xvar), Either_1.Either.right(3) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Either.ts docstrings", function () {
    it("lift", function () {
        assert.throws(function () {
            var undef = Either_1.Either.lift(function (x, y, z) { return undefined; });
            undef(1, 2, 3);
        });
    });
});
describe("Either.ts docstrings", function () {
    it("lift", function () {
        resetMathRandom();
        var throws = Either_1.Either.lift(function () { throw "x"; });
        var xvar = throws();
        ;
        assert.ok(myEq(Either_1.Either.left("x"), xvar), Either_1.Either.left("x") + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Either.ts docstrings", function () {
    it("try_", function () {
        resetMathRandom();
        var xvar = Either_1.Either.try_(Math.random, {});
        ;
        assert.ok(myEq(Either_1.Either.right(0.49884723907769635), xvar), Either_1.Either.right(0.49884723907769635) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Either.ts docstrings", function () {
    it("try_", function () {
        assert.throws(function () {
            Either_1.Either.try_(function () { return undefined; });
        });
    });
});
describe("Either.ts docstrings", function () {
    it("try_", function () {
        resetMathRandom();
        var xvar = Either_1.Either.try_(function () { throw "x"; });
        ;
        assert.ok(myEq(Either_1.Either.left("x"), xvar), Either_1.Either.left("x") + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Either.ts docstrings", function () {
    it("filter", function () {
        resetMathRandom();
        var xvar = Either_1.Either.right(-3)
            .filter(function (x) { return x >= 0; }, function (v) { return "got negative value: " + v; });
        ;
        assert.ok(myEq(Either_1.Either.left("got negative value: -3"), xvar), Either_1.Either.left("got negative value: -3") + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Either.ts docstrings", function () {
    it("match", function () {
        resetMathRandom();
        var xvar = Either_1.Either.right(5).match({
            Left: function (x) { return "left " + x; },
            Right: function (x) { return "right " + x; }
        });
        ;
        assert.ok(myEq("right 5", xvar), "right 5" + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Either.ts docstrings", function () {
    it("filter", function () {
        resetMathRandom();
        var xvar = Either_1.Either.right(-3)
            .filter(function (x) { return x >= 0; }, function (v) { return "got negative value: " + v; });
        ;
        assert.ok(myEq(Either_1.Either.left("got negative value: -3"), xvar), Either_1.Either.left("got negative value: -3") + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Either.ts docstrings", function () {
    it("match", function () {
        resetMathRandom();
        var xvar = Either_1.Either.right(5).match({
            Left: function (x) { return "left " + x; },
            Right: function (x) { return "right " + x; }
        });
        ;
        assert.ok(myEq("right 5", xvar), "right 5" + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
//# sourceMappingURL=apidoc-Either.js.map