"use strict";
exports.__esModule = true;
var Vector_1 = require("../src/Vector");
var HashSet_1 = require("../src/HashSet");
var assert = require("assert");
function myEq(a, b) {
    if (a === null && b === null) {
        return true;
    }
    if ((a === null) !== (b === null)) {
        return false;
    }
    if (a === undefined && b === undefined) {
        return true;
    }
    if ((a === undefined) !== (b === undefined)) {
        return false;
    }
    if (a.isSome && b.isSome &&
        a.isSome() && b.isSome()) {
        // workaround for Option<array> equality
        // useful in HashMap tests
        return myEq(a.getOrThrow(), b.getOrThrow());
    }
    if (a.toArray) {
        // workaround for the zip test Vector.of([1,"a"]) equality
        // real Vector returns false, compilation error otherwise
        return myEq(a.toArray(), b.toArray());
    }
    if (a.equals) {
        return a.equals(b);
    }
    if (Array.isArray(a)) {
        if (a.length !== b.length) {
            return false;
        }
        for (var i = 0; i < a.length; i++) {
            if (!myEq(a[i], b[i])) {
                return false;
            }
        }
        return true;
    }
    return JSON.stringify(a) === JSON.stringify(b);
}
// adding date support to myEq above isn't enough because I have Option<Date>
// in one of the tests...
Date.prototype.equals = function (other) { return this.getTime() === other.getTime(); };
var randomValues = [0.49884723907769635, 0.3226548779864311];
var randomIndex = 0;
var origMathRandom = Math.random;
var mockMathRandom = function () { return randomValues[(randomIndex++) % randomValues.length]; };
function resetMathRandom() {
    randomIndex = 0;
    Math.random = mockMathRandom;
}
describe("Foldable.ts docstrings", function () {
    it("fold", function () {
        resetMathRandom();
        var xvar = HashSet_1.HashSet.of(1, 2, 3).fold(0, function (a, b) { return a + b; });
        ;
        assert.ok(myEq(6, xvar), 6 + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Foldable.ts docstrings", function () {
    it("foldLeft", function () {
        resetMathRandom();
        var xvar = Vector_1.Vector.of("a", "b", "c").foldLeft("!", function (xs, x) { return x + xs; });
        ;
        assert.ok(myEq("cba!", xvar), "cba!" + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Foldable.ts docstrings", function () {
    it("foldRight", function () {
        resetMathRandom();
        var xvar = Vector_1.Vector.of("a", "b", "c").foldRight("!", function (x, xs) { return xs + x; });
        assert.ok(myEq("!cba", xvar), "!cba" + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
//# sourceMappingURL=apidoc-Foldable.js.map