"use strict";
exports.__esModule = true;
var Function_1 = require("../src/Function");
var assert = require("assert");
function myEq(a, b) {
    if (a === null && b === null) {
        return true;
    }
    if ((a === null) !== (b === null)) {
        return false;
    }
    if (a === undefined && b === undefined) {
        return true;
    }
    if ((a === undefined) !== (b === undefined)) {
        return false;
    }
    if (a.isSome && b.isSome &&
        a.isSome() && b.isSome()) {
        // workaround for Option<array> equality
        // useful in HashMap tests
        return myEq(a.getOrThrow(), b.getOrThrow());
    }
    if (a.toArray) {
        // workaround for the zip test Vector.of([1,"a"]) equality
        // real Vector returns false, compilation error otherwise
        return myEq(a.toArray(), b.toArray());
    }
    if (a.equals) {
        return a.equals(b);
    }
    if (Array.isArray(a)) {
        if (a.length !== b.length) {
            return false;
        }
        for (var i = 0; i < a.length; i++) {
            if (!myEq(a[i], b[i])) {
                return false;
            }
        }
        return true;
    }
    return JSON.stringify(a) === JSON.stringify(b);
}
// adding date support to myEq above isn't enough because I have Option<Date>
// in one of the tests...
Date.prototype.equals = function (other) { return this.getTime() === other.getTime(); };
var randomValues = [0.49884723907769635, 0.3226548779864311];
var randomIndex = 0;
var origMathRandom = Math.random;
var mockMathRandom = function () { return randomValues[(randomIndex++) % randomValues.length]; };
function resetMathRandom() {
    randomIndex = 0;
    Math.random = mockMathRandom;
}
describe("Function.ts docstrings", function () {
    // no result to compare the output to, just make sure this compiles
    var plus5 = Function_1.Function2.of(function (x, y) { return x + y; })
        .curried()(5);
    assert.equal(6, plus5(1));
});
describe("Function.ts docstrings", function () {
    // no result to compare the output to, just make sure this compiles
    var plus5 = Function_1.Function2.of(function (x, y) { return x + y; })
        .apply1(5);
    assert.equal(6, plus5(1));
});
describe("Function.ts docstrings", function () {
    // no result to compare the output to, just make sure this compiles
    var plus5 = Function_1.Function3.of(function (x, y, z) { return x + y + z; })
        .apply1(5);
    assert.equal(8, plus5(1, 2));
});
describe("Function.ts docstrings", function () {
    // no result to compare the output to, just make sure this compiles
    var plus54 = Function_1.Function3.of(function (x, y, z) { return x + y + z; })
        .apply2(5, 4);
    assert.equal(12, plus54(3));
});
describe("Function.ts docstrings", function () {
    // no result to compare the output to, just make sure this compiles
    var plus5 = Function_1.Function4.of(function (x, y, z, a) { return x + y + z + a; })
        .apply1(5);
    assert.equal(11, plus5(1, 2, 3));
});
describe("Function.ts docstrings", function () {
    // no result to compare the output to, just make sure this compiles
    var plus51 = Function_1.Function4.of(function (x, y, z, a) { return x + y + z + a; })
        .apply2(5, 1);
    assert.equal(11, plus51(2, 3));
});
describe("Function.ts docstrings", function () {
    // no result to compare the output to, just make sure this compiles
    var plus512 = Function_1.Function4.of(function (x, y, z, a) { return x + y + z + a; })
        .apply3(5, 1, 2);
    assert.equal(11, plus512(3));
});
describe("Function.ts docstrings", function () {
    // no result to compare the output to, just make sure this compiles
    var plus5 = Function_1.Function5.of(function (x, y, z, a, b) { return x + y + z + a + b; })
        .apply1(5);
    assert.equal(15, plus5(1, 2, 3, 4));
});
describe("Function.ts docstrings", function () {
    // no result to compare the output to, just make sure this compiles
    var plus51 = Function_1.Function5.of(function (x, y, z, a, b) { return x + y + z + a + b; })
        .apply2(5, 1);
    assert.equal(15, plus51(2, 3, 4));
});
describe("Function.ts docstrings", function () {
    // no result to compare the output to, just make sure this compiles
    var plus512 = Function_1.Function5.of(function (x, y, z, a, b) { return x + y + z + a + b; })
        .apply3(5, 1, 2);
    assert.equal(15, plus512(3, 4));
});
describe("Function.ts docstrings", function () {
    // no result to compare the output to, just make sure this compiles
    var plus5123 = Function_1.Function5.of(function (x, y, z, a, b) { return x + y + z + a + b; })
        .apply4(5, 1, 2, 3);
    assert.equal(15, plus5123(4));
});
//# sourceMappingURL=apidoc-Function.js.map