"use strict";
exports.__esModule = true;
var Vector_1 = require("../src/Vector");
var HashMap_1 = require("../src/HashMap");
var Option_1 = require("../src/Option");
var assert = require("assert");
function myEq(a, b) {
    if (a === null && b === null) {
        return true;
    }
    if ((a === null) !== (b === null)) {
        return false;
    }
    if (a === undefined && b === undefined) {
        return true;
    }
    if ((a === undefined) !== (b === undefined)) {
        return false;
    }
    if (a.isSome && b.isSome &&
        a.isSome() && b.isSome()) {
        // workaround for Option<array> equality
        // useful in HashMap tests
        return myEq(a.getOrThrow(), b.getOrThrow());
    }
    if (a.toArray) {
        // workaround for the zip test Vector.of([1,"a"]) equality
        // real Vector returns false, compilation error otherwise
        return myEq(a.toArray(), b.toArray());
    }
    if (a.equals) {
        return a.equals(b);
    }
    if (Array.isArray(a)) {
        if (a.length !== b.length) {
            return false;
        }
        for (var i = 0; i < a.length; i++) {
            if (!myEq(a[i], b[i])) {
                return false;
            }
        }
        return true;
    }
    return JSON.stringify(a) === JSON.stringify(b);
}
// adding date support to myEq above isn't enough because I have Option<Date>
// in one of the tests...
Date.prototype.equals = function (other) { return this.getTime() === other.getTime(); };
var randomValues = [0.49884723907769635, 0.3226548779864311];
var randomIndex = 0;
var origMathRandom = Math.random;
var mockMathRandom = function () { return randomValues[(randomIndex++) % randomValues.length]; };
function resetMathRandom() {
    randomIndex = 0;
    Math.random = mockMathRandom;
}
describe("HashMap.ts docstrings", function () {
    // no result to compare the output to, just make sure this compiles
    HashMap_1.HashMap.of([1, "a"], [2, "b"]);
});
describe("HashMap.ts docstrings", function () {
    // no result to compare the output to, just make sure this compiles
    HashMap_1.HashMap.ofIterable(Vector_1.Vector.of([1, "a"], [2, "b"]));
});
describe("HashMap.ts docstrings", function () {
    it("ofObjectDictionary", function () {
        resetMathRandom();
        var xvar = HashMap_1.HashMap.ofObjectDictionary({ a: 1, b: 2 });
        assert.ok(myEq(HashMap_1.HashMap.of(["a", 1], ["b", 2]), xvar), HashMap_1.HashMap.of(["a", 1], ["b", 2]) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("HashMap.ts docstrings", function () {
    it("isEmpty", function () {
        resetMathRandom();
        var xvar = Vector_1.Vector.of(HashMap_1.HashMap.of([1, 2]), HashMap_1.HashMap.empty())
            .filter(HashMap_1.HashMap.isEmpty);
        assert.ok(myEq(Vector_1.Vector.of(HashMap_1.HashMap.empty()), xvar), Vector_1.Vector.of(HashMap_1.HashMap.empty()) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("HashMap.ts docstrings", function () {
    it("isNotEmpty", function () {
        resetMathRandom();
        var xvar = Vector_1.Vector.of(HashMap_1.HashMap.of([1, 2]), HashMap_1.HashMap.empty())
            .filter(HashMap_1.HashMap.isNotEmpty);
        assert.ok(myEq(Vector_1.Vector.of(HashMap_1.HashMap.of([1, 2])), xvar), Vector_1.Vector.of(HashMap_1.HashMap.of([1, 2])) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("HashMap.ts docstrings", function () {
    it("containsKey", function () {
        resetMathRandom();
        var xvar = HashMap_1.HashMap.of([1, "a"], [2, "b"]).containsKey(1);
        ;
        assert.ok(myEq(true, xvar), true + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("HashMap.ts docstrings", function () {
    it("containsKey", function () {
        resetMathRandom();
        var xvar = HashMap_1.HashMap.of([1, "a"], [2, "b"]).containsKey(3);
        ;
        assert.ok(myEq(false, xvar), false + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("HashMap.ts docstrings", function () {
    it("findAny", function () {
        resetMathRandom();
        var xvar = HashMap_1.HashMap.of([1, 'a'], [2, 'b'], [3, 'c'])
            .findAny(function (k, v) { return k >= 2 && v === "c"; });
        assert.ok(myEq(Option_1.Option.of([3, 'c']), xvar), Option_1.Option.of([3, 'c']) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("HashMap.ts docstrings", function () {
    it("findAny", function () {
        resetMathRandom();
        var xvar = HashMap_1.HashMap.of([1, 'a'], [2, 'b'], [3, 'c'])
            .findAny(function (k, v) { return k >= 3 && v === "b"; });
        assert.ok(myEq(Option_1.Option.none(), xvar), Option_1.Option.none() + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("HashMap.ts docstrings", function () {
    it("filterKeys", function () {
        resetMathRandom();
        var xvar = HashMap_1.HashMap.of([1, "a"], [2, "b"]).filterKeys(function (k) { return k % 2 === 0; });
        assert.ok(myEq(HashMap_1.HashMap.of([2, "b"]), xvar), HashMap_1.HashMap.of([2, "b"]) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("HashMap.ts docstrings", function () {
    it("filterValues", function () {
        resetMathRandom();
        var xvar = HashMap_1.HashMap.of([1, "a"], [2, "ab"]).filterValues(function (v) { return v.length > 1; });
        assert.ok(myEq(HashMap_1.HashMap.of([2, "ab"]), xvar), HashMap_1.HashMap.of([2, "ab"]) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("HashMap.ts docstrings", function () {
    it("fold", function () {
        resetMathRandom();
        var xvar = HashMap_1.HashMap.of([1, "a"], [2, "b"], [3, "c"])
            .fold([0, ""], function (_a, _b) {
            var a = _a[0], b = _a[1];
            var c = _b[0], d = _b[1];
            return [a + c, b > d ? b : d];
        });
        assert.ok(myEq([6, "c"], xvar), [6, "c"] + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("HashMap.ts docstrings", function () {
    it("foldLeft", function () {
        resetMathRandom();
        var xvar = HashMap_1.HashMap.of([1, "a"], [2, "bb"], [3, "ccc"])
            .foldLeft(0, function (soFar, _a) {
            var item = _a[0], val = _a[1];
            return soFar + val.length;
        });
        ;
        assert.ok(myEq(6, xvar), 6 + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("HashMap.ts docstrings", function () {
    it("foldRight", function () {
        resetMathRandom();
        var xvar = HashMap_1.HashMap.of([1, "a"], [2, "bb"], [3, "ccc"])
            .foldRight(0, function (_a, soFar) {
            var item = _a[0], value = _a[1];
            return soFar + value.length;
        });
        ;
        assert.ok(myEq(6, xvar), 6 + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("HashMap.ts docstrings", function () {
    it("toObjectDictionary", function () {
        resetMathRandom();
        var xvar = HashMap_1.HashMap.of(["a", 1], ["b", 2])
            .toObjectDictionary(function (x) { return x; });
        ;
        assert.ok(myEq({ a: 1, b: 2 }, xvar), { a: 1, b: 2 } + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("HashMap.ts docstrings", function () {
    it("toJsMap", function () {
        resetMathRandom();
        var xvar = HashMap_1.HashMap.of(["a", 1], ["b", 2])
            .toJsMap(function (x) { return x; });
        ;
        assert.ok(myEq(new Map([["a", 1], ["b", 2]]), xvar), new Map([["a", 1], ["b", 2]]) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
//# sourceMappingURL=apidoc-HashMap.js.map