"use strict";
exports.__esModule = true;
var Vector_1 = require("../src/Vector");
var HashSet_1 = require("../src/HashSet");
var Option_1 = require("../src/Option");
var assert = require("assert");
function myEq(a, b) {
    if (a === null && b === null) {
        return true;
    }
    if ((a === null) !== (b === null)) {
        return false;
    }
    if (a === undefined && b === undefined) {
        return true;
    }
    if ((a === undefined) !== (b === undefined)) {
        return false;
    }
    if (a.isSome && b.isSome &&
        a.isSome() && b.isSome()) {
        // workaround for Option<array> equality
        // useful in HashMap tests
        return myEq(a.getOrThrow(), b.getOrThrow());
    }
    if (a.toArray) {
        // workaround for the zip test Vector.of([1,"a"]) equality
        // real Vector returns false, compilation error otherwise
        return myEq(a.toArray(), b.toArray());
    }
    if (a.equals) {
        return a.equals(b);
    }
    if (Array.isArray(a)) {
        if (a.length !== b.length) {
            return false;
        }
        for (var i = 0; i < a.length; i++) {
            if (!myEq(a[i], b[i])) {
                return false;
            }
        }
        return true;
    }
    return JSON.stringify(a) === JSON.stringify(b);
}
// adding date support to myEq above isn't enough because I have Option<Date>
// in one of the tests...
Date.prototype.equals = function (other) { return this.getTime() === other.getTime(); };
var randomValues = [0.49884723907769635, 0.3226548779864311];
var randomIndex = 0;
var origMathRandom = Math.random;
var mockMathRandom = function () { return randomValues[(randomIndex++) % randomValues.length]; };
function resetMathRandom() {
    randomIndex = 0;
    Math.random = mockMathRandom;
}
describe("HashSet.ts docstrings", function () {
    it("isEmpty", function () {
        resetMathRandom();
        var xvar = Vector_1.Vector.of(HashSet_1.HashSet.of(1), HashSet_1.HashSet.empty())
            .filter(HashSet_1.HashSet.isEmpty);
        assert.ok(myEq(Vector_1.Vector.of(HashSet_1.HashSet.empty()), xvar), Vector_1.Vector.of(HashSet_1.HashSet.empty()) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("HashSet.ts docstrings", function () {
    it("isNotEmpty", function () {
        resetMathRandom();
        var xvar = Vector_1.Vector.of(HashSet_1.HashSet.of(1), HashSet_1.HashSet.empty())
            .filter(HashSet_1.HashSet.isNotEmpty);
        assert.ok(myEq(Vector_1.Vector.of(HashSet_1.HashSet.of(1)), xvar), Vector_1.Vector.of(HashSet_1.HashSet.of(1)) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("HashSet.ts docstrings", function () {
    it("mapOption", function () {
        resetMathRandom();
        var xvar = HashSet_1.HashSet.of(1, 2, 6).mapOption(function (x) { return x % 2 === 0 ?
            Option_1.Option.of(x + 1) : Option_1.Option.none(); });
        assert.ok(myEq(HashSet_1.HashSet.of(3, 7), xvar), HashSet_1.HashSet.of(3, 7) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("HashSet.ts docstrings", function () {
    it("findAny", function () {
        resetMathRandom();
        var xvar = HashSet_1.HashSet.of(1, 2, 3).findAny(function (x) { return x >= 3; });
        assert.ok(myEq(Option_1.Option.of(3), xvar), Option_1.Option.of(3) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("HashSet.ts docstrings", function () {
    it("findAny", function () {
        resetMathRandom();
        var xvar = HashSet_1.HashSet.of(1, 2, 3).findAny(function (x) { return x >= 4; });
        assert.ok(myEq(Option_1.Option.none(), xvar), Option_1.Option.none() + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("HashSet.ts docstrings", function () {
    it("fold", function () {
        resetMathRandom();
        var xvar = HashSet_1.HashSet.of(1, 2, 3).fold(0, function (a, b) { return a + b; });
        ;
        assert.ok(myEq(6, xvar), 6 + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("HashSet.ts docstrings", function () {
    it("foldLeft", function () {
        resetMathRandom();
        var xvar = HashSet_1.HashSet.of("a", "bb", "ccc").foldLeft(0, function (soFar, item) { return soFar + item.length; });
        ;
        assert.ok(myEq(6, xvar), 6 + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("HashSet.ts docstrings", function () {
    it("foldRight", function () {
        resetMathRandom();
        var xvar = HashSet_1.HashSet.of("a", "bb", "ccc").foldRight(0, function (item, soFar) { return soFar + item.length; });
        ;
        assert.ok(myEq(6, xvar), 6 + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("HashSet.ts docstrings", function () {
    it("toArray", function () {
        resetMathRandom();
        var xvar = HashSet_1.HashSet.of(1, 2, 3).toArray().sort();
        assert.ok(myEq([1, 2, 3], xvar), [1, 2, 3] + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("HashSet.ts docstrings", function () {
    it("toArray", function () {
        resetMathRandom();
        var xvar = HashSet_1.HashSet.of(1, 2, 3).toArray({ sortOn: function (x) { return x; } });
        assert.ok(myEq([1, 2, 3], xvar), [1, 2, 3] + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("HashSet.ts docstrings", function () {
    it("toArray", function () {
        resetMathRandom();
        var xvar = HashSet_1.HashSet.of(1, 2, 3).toArray({ sortBy: function (x, y) { return x - y; } });
        assert.ok(myEq([1, 2, 3], xvar), [1, 2, 3] + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("HashSet.ts docstrings", function () {
    it("partition", function () {
        resetMathRandom();
        var xvar = HashSet_1.HashSet.of(1, 2, 3, 4).partition(function (x) { return x % 2 === 0; });
        assert.ok(myEq([HashSet_1.HashSet.of(2, 4), HashSet_1.HashSet.of(1, 3)], xvar), [HashSet_1.HashSet.of(2, 4), HashSet_1.HashSet.of(1, 3)] + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("HashSet.ts docstrings", function () {
    it("toJsSet", function () {
        resetMathRandom();
        var xvar = HashSet_1.HashSet.of("a", "b").toJsSet(function (x) { return x; });
        ;
        assert.ok(myEq(new Set(["a", "b"]), xvar), new Set(["a", "b"]) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("HashSet.ts docstrings", function () {
    it("mkString", function () {
        resetMathRandom();
        var xvar = HashSet_1.HashSet.of(1, 2, 3).mkString(", ");
        assert.ok(myEq("1, 2, 3", xvar), "1, 2, 3" + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
//# sourceMappingURL=apidoc-HashSet.js.map