"use strict";
exports.__esModule = true;
var HashSet_1 = require("../src/HashSet");
var assert = require("assert");
function myEq(a, b) {
    if (a === null && b === null) {
        return true;
    }
    if ((a === null) !== (b === null)) {
        return false;
    }
    if (a === undefined && b === undefined) {
        return true;
    }
    if ((a === undefined) !== (b === undefined)) {
        return false;
    }
    if (a.isSome && b.isSome &&
        a.isSome() && b.isSome()) {
        // workaround for Option<array> equality
        // useful in HashMap tests
        return myEq(a.getOrThrow(), b.getOrThrow());
    }
    if (a.toArray) {
        // workaround for the zip test Vector.of([1,"a"]) equality
        // real Vector returns false, compilation error otherwise
        return myEq(a.toArray(), b.toArray());
    }
    if (a.equals) {
        return a.equals(b);
    }
    if (Array.isArray(a)) {
        if (a.length !== b.length) {
            return false;
        }
        for (var i = 0; i < a.length; i++) {
            if (!myEq(a[i], b[i])) {
                return false;
            }
        }
        return true;
    }
    return JSON.stringify(a) === JSON.stringify(b);
}
// adding date support to myEq above isn't enough because I have Option<Date>
// in one of the tests...
Date.prototype.equals = function (other) { return this.getTime() === other.getTime(); };
var randomValues = [0.49884723907769635, 0.3226548779864311];
var randomIndex = 0;
var origMathRandom = Math.random;
var mockMathRandom = function () { return randomValues[(randomIndex++) % randomValues.length]; };
function resetMathRandom() {
    randomIndex = 0;
    Math.random = mockMathRandom;
}
describe("ISet.ts docstrings", function () {
    it("toArray", function () {
        resetMathRandom();
        var xvar = HashSet_1.HashSet.of(1, 2, 3).toArray().sort();
        assert.ok(myEq([1, 2, 3], xvar), [1, 2, 3] + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("ISet.ts docstrings", function () {
    it("toArray", function () {
        resetMathRandom();
        var xvar = HashSet_1.HashSet.of(1, 2, 3).toArray({ sortOn: function (x) { return x; } });
        assert.ok(myEq([1, 2, 3], xvar), [1, 2, 3] + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("ISet.ts docstrings", function () {
    it("toArray", function () {
        resetMathRandom();
        var xvar = HashSet_1.HashSet.of(1, 2, 3).toArray({ sortBy: function (x, y) { return x - y; } });
        assert.ok(myEq([1, 2, 3], xvar), [1, 2, 3] + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("ISet.ts docstrings", function () {
    it("toJsSet", function () {
        resetMathRandom();
        var xvar = HashSet_1.HashSet.of("a", "b").toJsSet(function (x) { return x; });
        ;
        assert.ok(myEq(new Set(["a", "b"]), xvar), new Set(["a", "b"]) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
//# sourceMappingURL=apidoc-ISet.js.map