"use strict";
exports.__esModule = true;
var Vector_1 = require("../src/Vector");
var Option_1 = require("../src/Option");
var assert = require("assert");
function myEq(a, b) {
    if (a === null && b === null) {
        return true;
    }
    if ((a === null) !== (b === null)) {
        return false;
    }
    if (a === undefined && b === undefined) {
        return true;
    }
    if ((a === undefined) !== (b === undefined)) {
        return false;
    }
    if (a.isSome && b.isSome &&
        a.isSome() && b.isSome()) {
        // workaround for Option<array> equality
        // useful in HashMap tests
        return myEq(a.getOrThrow(), b.getOrThrow());
    }
    if (a.toArray) {
        // workaround for the zip test Vector.of([1,"a"]) equality
        // real Vector returns false, compilation error otherwise
        return myEq(a.toArray(), b.toArray());
    }
    if (a.equals) {
        return a.equals(b);
    }
    if (Array.isArray(a)) {
        if (a.length !== b.length) {
            return false;
        }
        for (var i = 0; i < a.length; i++) {
            if (!myEq(a[i], b[i])) {
                return false;
            }
        }
        return true;
    }
    return JSON.stringify(a) === JSON.stringify(b);
}
// adding date support to myEq above isn't enough because I have Option<Date>
// in one of the tests...
Date.prototype.equals = function (other) { return this.getTime() === other.getTime(); };
var randomValues = [0.49884723907769635, 0.3226548779864311];
var randomIndex = 0;
var origMathRandom = Math.random;
var mockMathRandom = function () { return randomValues[(randomIndex++) % randomValues.length]; };
function resetMathRandom() {
    randomIndex = 0;
    Math.random = mockMathRandom;
}
describe("Option.ts docstrings", function () {
    // no result to compare the output to, just make sure this compiles
    Option_1.Option.of(5);
    Option_1.Option.none();
    Option_1.Option.of(5).map(function (x) { return x * 2; });
});
describe("Option.ts docstrings", function () {
    // no result to compare the output to, just make sure this compiles
    var opt = Option_1.Option.of(5);
    if (opt.isSome()) {
        opt.get();
    }
});
describe("Option.ts docstrings", function () {
    it("T", function () {
        resetMathRandom();
        var xvar = Option_1.Option.of(5).isSome();
        assert.ok(myEq(true, xvar), true + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Option.ts docstrings", function () {
    it("T", function () {
        resetMathRandom();
        var xvar = Option_1.Option.of(undefined).isSome();
        assert.ok(myEq(false, xvar), false + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Option.ts docstrings", function () {
    it("T", function () {
        resetMathRandom();
        var xvar = Option_1.Option.of(null).isSome();
        assert.ok(myEq(true, xvar), true + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Option.ts docstrings", function () {
    it("ofNullable", function () {
        resetMathRandom();
        var xvar = Option_1.Option.ofNullable(5).isSome();
        assert.ok(myEq(true, xvar), true + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Option.ts docstrings", function () {
    it("ofNullable", function () {
        resetMathRandom();
        var xvar = Option_1.Option.ofNullable(undefined).isSome();
        assert.ok(myEq(false, xvar), false + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Option.ts docstrings", function () {
    it("ofNullable", function () {
        resetMathRandom();
        var xvar = Option_1.Option.ofNullable(null).isSome();
        assert.ok(myEq(false, xvar), false + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Option.ts docstrings", function () {
    it("some", function () {
        resetMathRandom();
        var xvar = Option_1.Option.some(5).isSome();
        assert.ok(myEq(true, xvar), true + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Option.ts docstrings", function () {
    it("some", function () {
        assert.throws(function () {
            Option_1.Option.some(undefined).isSome();
        });
    });
});
describe("Option.ts docstrings", function () {
    it("some", function () {
        resetMathRandom();
        var xvar = Option_1.Option.some(null).isSome();
        assert.ok(myEq(true, xvar), true + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Option.ts docstrings", function () {
    it("isSome", function () {
        resetMathRandom();
        var xvar = Vector_1.Vector.of(Option_1.Option.of(2), Option_1.Option.none())
            .filter(Option_1.Option.isSome)
            .map(function (o) { return o.get(); });
        assert.ok(myEq(Vector_1.Vector.of(2), xvar), Vector_1.Vector.of(2) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Option.ts docstrings", function () {
    it("isNone", function () {
        resetMathRandom();
        var xvar = Vector_1.Vector.of(Option_1.Option.of(2), Option_1.Option.none())
            .filter(Option_1.Option.isNone);
        assert.ok(myEq(Vector_1.Vector.of(Option_1.Option.none()), xvar), Vector_1.Vector.of(Option_1.Option.none()) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Option.ts docstrings", function () {
    it("sequence", function () {
        resetMathRandom();
        var xvar = Option_1.Option.sequence(Vector_1.Vector.of(Option_1.Option.of(1), Option_1.Option.of(2)));
        assert.ok(myEq(Option_1.Option.of(Vector_1.Vector.of(1, 2)), xvar), Option_1.Option.of(Vector_1.Vector.of(1, 2)) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Option.ts docstrings", function () {
    it("sequence", function () {
        resetMathRandom();
        var xvar = Option_1.Option.sequence(Vector_1.Vector.of(Option_1.Option.of(1), Option_1.Option.none()));
        assert.ok(myEq(Option_1.Option.none(), xvar), Option_1.Option.none() + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Option.ts docstrings", function () {
    it("traverse", function () {
        resetMathRandom();
        var getUserById = function (x) { return x > 0 ?
            Option_1.Option.of("user" + x.toString()) : Option_1.Option.none(); };
        var xvar = Option_1.Option.traverse([4, 3, 2], getUserById);
        ;
        assert.ok(myEq(Option_1.Option.of(Vector_1.Vector.of("user4", "user3", "user2")), xvar), Option_1.Option.of(Vector_1.Vector.of("user4", "user3", "user2")) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Option.ts docstrings", function () {
    it("traverse", function () {
        resetMathRandom();
        var getUserById = function (x) { return x > 0 ?
            Option_1.Option.of("user" + x.toString()) : Option_1.Option.none(); };
        var xvar = Option_1.Option.traverse([4, -3, 2], getUserById);
        ;
        assert.ok(myEq(Option_1.Option.none(), xvar), Option_1.Option.none() + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Option.ts docstrings", function () {
    it("liftA2", function () {
        resetMathRandom();
        var lifted = Option_1.Option.liftA2(function (x, y) { return x + y; });
        var xvar = lifted(Option_1.Option.of(5), Option_1.Option.of(6));
        ;
        assert.ok(myEq(Option_1.Option.of(11), xvar), Option_1.Option.of(11) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Option.ts docstrings", function () {
    it("liftA2", function () {
        resetMathRandom();
        var lifted2 = Option_1.Option.liftA2(function (x, y) { return x + y; });
        var xvar = lifted2(Option_1.Option.of(5), Option_1.Option.none());
        ;
        assert.ok(myEq(Option_1.Option.none(), xvar), Option_1.Option.none() + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Option.ts docstrings", function () {
    it("liftAp", function () {
        resetMathRandom();
        var lifted = Option_1.Option.liftAp(function (x) { return x.a + x.b + x.c; });
        var xvar = lifted({ a: Option_1.Option.of(5), b: Option_1.Option.of(6), c: Option_1.Option.of(3) });
        ;
        assert.ok(myEq(Option_1.Option.of(14), xvar), Option_1.Option.of(14) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Option.ts docstrings", function () {
    it("liftAp", function () {
        resetMathRandom();
        var lifted = Option_1.Option.liftAp(function (x) { return x.a + x.b; });
        var xvar = lifted({ a: Option_1.Option.of(5), b: Option_1.Option.none() });
        ;
        assert.ok(myEq(Option_1.Option.none(), xvar), Option_1.Option.none() + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Option.ts docstrings", function () {
    it("lift", function () {
        resetMathRandom();
        var plus = Option_1.Option.lift(function (x, y) { return x + y; });
        var xvar = plus(1, 2);
        ;
        assert.ok(myEq(Option_1.Option.of(3), xvar), Option_1.Option.of(3) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Option.ts docstrings", function () {
    it("lift", function () {
        resetMathRandom();
        var undef = Option_1.Option.lift(function (x) { return undefined; });
        var xvar = undef(1);
        ;
        assert.ok(myEq(Option_1.Option.none(), xvar), Option_1.Option.none() + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Option.ts docstrings", function () {
    it("lift", function () {
        resetMathRandom();
        var nl = Option_1.Option.lift(function (x, y, z) { return null; });
        var xvar = nl(1, 2, 3);
        ;
        assert.ok(myEq(Option_1.Option.some(null), xvar), Option_1.Option.some(null) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Option.ts docstrings", function () {
    it("lift", function () {
        resetMathRandom();
        var throws = Option_1.Option.lift(function (x, y) { throw "x"; });
        var xvar = throws(1, 2);
        ;
        assert.ok(myEq(Option_1.Option.none(), xvar), Option_1.Option.none() + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Option.ts docstrings", function () {
    it("liftNullable", function () {
        resetMathRandom();
        var plus = Option_1.Option.liftNullable(function (x, y) { return x + y; });
        var xvar = plus(1, 2);
        ;
        assert.ok(myEq(Option_1.Option.of(3), xvar), Option_1.Option.of(3) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Option.ts docstrings", function () {
    it("liftNullable", function () {
        resetMathRandom();
        var undef = Option_1.Option.liftNullable(function (x, y, z) { return undefined; });
        var xvar = undef(1, 2, "");
        ;
        assert.ok(myEq(Option_1.Option.none(), xvar), Option_1.Option.none() + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Option.ts docstrings", function () {
    it("liftNullable", function () {
        resetMathRandom();
        var nl = Option_1.Option.liftNullable(function (x) { return null; });
        var xvar = nl(1);
        ;
        assert.ok(myEq(Option_1.Option.none(), xvar), Option_1.Option.none() + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Option.ts docstrings", function () {
    it("liftNullable", function () {
        resetMathRandom();
        var throws = Option_1.Option.liftNullable(function (x, y) { throw "x"; });
        var xvar = throws(1, 2);
        ;
        assert.ok(myEq(Option_1.Option.none(), xvar), Option_1.Option.none() + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Option.ts docstrings", function () {
    it("try_", function () {
        resetMathRandom();
        var xvar = Option_1.Option.try_(Math.random);
        ;
        assert.ok(myEq(Option_1.Option.of(0.49884723907769635), xvar), Option_1.Option.of(0.49884723907769635) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Option.ts docstrings", function () {
    it("try_", function () {
        resetMathRandom();
        var xvar = Option_1.Option.try_(function () { return undefined; });
        ;
        assert.ok(myEq(Option_1.Option.none(), xvar), Option_1.Option.none() + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Option.ts docstrings", function () {
    it("try_", function () {
        resetMathRandom();
        var xvar = Option_1.Option.try_(function () { return null; });
        ;
        assert.ok(myEq(Option_1.Option.of(null), xvar), Option_1.Option.of(null) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Option.ts docstrings", function () {
    it("try_", function () {
        resetMathRandom();
        var xvar = Option_1.Option.try_(function () { throw "x"; });
        ;
        assert.ok(myEq(Option_1.Option.none(), xvar), Option_1.Option.none() + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Option.ts docstrings", function () {
    it("tryNullable", function () {
        resetMathRandom();
        var xvar = Option_1.Option.tryNullable(Math.random);
        ;
        assert.ok(myEq(Option_1.Option.of(0.49884723907769635), xvar), Option_1.Option.of(0.49884723907769635) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Option.ts docstrings", function () {
    it("tryNullable", function () {
        resetMathRandom();
        var xvar = Option_1.Option.tryNullable(function () { return undefined; });
        ;
        assert.ok(myEq(Option_1.Option.none(), xvar), Option_1.Option.none() + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Option.ts docstrings", function () {
    it("tryNullable", function () {
        resetMathRandom();
        var xvar = Option_1.Option.tryNullable(function () { return null; });
        ;
        assert.ok(myEq(Option_1.Option.none(), xvar), Option_1.Option.none() + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Option.ts docstrings", function () {
    it("tryNullable", function () {
        resetMathRandom();
        var xvar = Option_1.Option.tryNullable(function () { throw "x"; });
        ;
        assert.ok(myEq(Option_1.Option.none(), xvar), Option_1.Option.none() + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Option.ts docstrings", function () {
    it("getOrUndefined", function () {
        resetMathRandom();
        var xvar = Option_1.Option.of(5).getOrUndefined();
        assert.ok(myEq(5, xvar), 5 + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Option.ts docstrings", function () {
    it("getOrUndefined", function () {
        resetMathRandom();
        var xvar = Option_1.Option.none().getOrUndefined();
        assert.ok(myEq(undefined, xvar), undefined + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Option.ts docstrings", function () {
    it("getOrNull", function () {
        resetMathRandom();
        var xvar = Option_1.Option.of(5).getOrNull();
        assert.ok(myEq(5, xvar), 5 + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Option.ts docstrings", function () {
    it("getOrNull", function () {
        resetMathRandom();
        var xvar = Option_1.Option.none().getOrNull();
        assert.ok(myEq(null, xvar), null + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Option.ts docstrings", function () {
    it("getOrCall", function () {
        resetMathRandom();
        var xvar = Option_1.Option.of(5).getOrCall(function () { return 6; });
        assert.ok(myEq(5, xvar), 5 + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Option.ts docstrings", function () {
    it("getOrCall", function () {
        resetMathRandom();
        var xvar = Option_1.Option.none().getOrCall(function () { return 6; });
        assert.ok(myEq(6, xvar), 6 + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Option.ts docstrings", function () {
    it("map", function () {
        resetMathRandom();
        var xvar = Option_1.Option.of(5).map(function (x) { return x * 2; });
        assert.ok(myEq(Option_1.Option.of(10), xvar), Option_1.Option.of(10) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Option.ts docstrings", function () {
    it("map", function () {
        resetMathRandom();
        var xvar = Option_1.Option.of(5).map(function (x) { return null; });
        assert.ok(myEq(Option_1.Option.of(null), xvar), Option_1.Option.of(null) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Option.ts docstrings", function () {
    it("mapNullable", function () {
        resetMathRandom();
        var xvar = Option_1.Option.of(5).mapNullable(function (x) { return x * 2; });
        assert.ok(myEq(Option_1.Option.of(10), xvar), Option_1.Option.of(10) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Option.ts docstrings", function () {
    it("mapNullable", function () {
        resetMathRandom();
        var xvar = Option_1.Option.of(5).mapNullable(function (x) { return null; });
        assert.ok(myEq(Option_1.Option.none(), xvar), Option_1.Option.none() + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Option.ts docstrings", function () {
    it("match", function () {
        resetMathRandom();
        var xvar = Option_1.Option.of(5).match({
            Some: function (x) { return "got " + x; },
            None: function () { return "got nothing!"; }
        });
        ;
        assert.ok(myEq("got 5", xvar), "got 5" + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Option.ts docstrings", function () {
    it("getOrUndefined", function () {
        resetMathRandom();
        var xvar = Option_1.Option.of(5).getOrUndefined();
        assert.ok(myEq(5, xvar), 5 + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Option.ts docstrings", function () {
    it("getOrUndefined", function () {
        resetMathRandom();
        var xvar = Option_1.Option.none().getOrUndefined();
        assert.ok(myEq(undefined, xvar), undefined + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Option.ts docstrings", function () {
    it("getOrNull", function () {
        resetMathRandom();
        var xvar = Option_1.Option.of(5).getOrNull();
        assert.ok(myEq(5, xvar), 5 + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Option.ts docstrings", function () {
    it("getOrNull", function () {
        resetMathRandom();
        var xvar = Option_1.Option.none().getOrNull();
        assert.ok(myEq(null, xvar), null + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Option.ts docstrings", function () {
    it("getOrCall", function () {
        resetMathRandom();
        var xvar = Option_1.Option.of(5).getOrCall(function () { return 6; });
        assert.ok(myEq(5, xvar), 5 + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Option.ts docstrings", function () {
    it("getOrCall", function () {
        resetMathRandom();
        var xvar = Option_1.Option.none().getOrCall(function () { return 6; });
        assert.ok(myEq(6, xvar), 6 + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Option.ts docstrings", function () {
    it("map", function () {
        resetMathRandom();
        var xvar = Option_1.Option.of(5).map(function (x) { return x * 2; });
        assert.ok(myEq(Option_1.Option.of(10), xvar), Option_1.Option.of(10) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Option.ts docstrings", function () {
    it("map", function () {
        resetMathRandom();
        var xvar = Option_1.Option.of(5).map(function (x) { return null; });
        assert.ok(myEq(Option_1.Option.of(null), xvar), Option_1.Option.of(null) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Option.ts docstrings", function () {
    it("mapNullable", function () {
        resetMathRandom();
        var xvar = Option_1.Option.of(5).mapNullable(function (x) { return x * 2; });
        assert.ok(myEq(Option_1.Option.of(10), xvar), Option_1.Option.of(10) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Option.ts docstrings", function () {
    it("mapNullable", function () {
        resetMathRandom();
        var xvar = Option_1.Option.of(5).mapNullable(function (x) { return null; });
        assert.ok(myEq(Option_1.Option.none(), xvar), Option_1.Option.none() + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Option.ts docstrings", function () {
    it("match", function () {
        resetMathRandom();
        var xvar = Option_1.Option.of(5).match({
            Some: function (x) { return "got " + x; },
            None: function () { return "got nothing!"; }
        });
        ;
        assert.ok(myEq("got 5", xvar), "got 5" + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
//# sourceMappingURL=apidoc-Option.js.map