"use strict";
exports.__esModule = true;
var Vector_1 = require("../src/Vector");
var Predicate_1 = require("../src/Predicate");
var assert = require("assert");
function myEq(a, b) {
    if (a === null && b === null) {
        return true;
    }
    if ((a === null) !== (b === null)) {
        return false;
    }
    if (a === undefined && b === undefined) {
        return true;
    }
    if ((a === undefined) !== (b === undefined)) {
        return false;
    }
    if (a.isSome && b.isSome &&
        a.isSome() && b.isSome()) {
        // workaround for Option<array> equality
        // useful in HashMap tests
        return myEq(a.getOrThrow(), b.getOrThrow());
    }
    if (a.toArray) {
        // workaround for the zip test Vector.of([1,"a"]) equality
        // real Vector returns false, compilation error otherwise
        return myEq(a.toArray(), b.toArray());
    }
    if (a.equals) {
        return a.equals(b);
    }
    if (Array.isArray(a)) {
        if (a.length !== b.length) {
            return false;
        }
        for (var i = 0; i < a.length; i++) {
            if (!myEq(a[i], b[i])) {
                return false;
            }
        }
        return true;
    }
    return JSON.stringify(a) === JSON.stringify(b);
}
// adding date support to myEq above isn't enough because I have Option<Date>
// in one of the tests...
Date.prototype.equals = function (other) { return this.getTime() === other.getTime(); };
var randomValues = [0.49884723907769635, 0.3226548779864311];
var randomIndex = 0;
var origMathRandom = Math.random;
var mockMathRandom = function () { return randomValues[(randomIndex++) % randomValues.length]; };
function resetMathRandom() {
    randomIndex = 0;
    Math.random = mockMathRandom;
}
describe("Predicate.ts docstrings", function () {
    it("WithEquality", function () {
        resetMathRandom();
        var check = Predicate_1.Predicate.of(function (x) { return x > 10; }).and(function (x) { return x < 20; });
        check(12); // => true
        var xvar = check(21);
        ;
        assert.ok(myEq(false, xvar), false + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Predicate.ts docstrings", function () {
    it("WithEquality", function () {
        resetMathRandom();
        var xvar = Vector_1.Vector.of(1, 2, 3, 4, 5).filter(Predicate_1.Predicate.isIn([2, 3]).negate());
        assert.ok(myEq(Vector_1.Vector.of(1, 4, 5), xvar), Vector_1.Vector.of(1, 4, 5) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Predicate.ts docstrings", function () {
    // no result to compare the output to, just make sure this compiles
    Predicate_1.Predicate.of(function (x) { return x > 10; }).and(function (x) { return x < 20; });
});
describe("Predicate.ts docstrings", function () {
    // no result to compare the output to, just make sure this compiles
    Predicate_1.Predicate.of(function (x) { return x < 5; }).or(function (x) { return x > 10; });
});
//# sourceMappingURL=apidoc-Predicate.js.map