"use strict";
exports.__esModule = true;
var Vector_1 = require("../src/Vector");
var HashSet_1 = require("../src/HashSet");
var HashMap_1 = require("../src/HashMap");
var Stream_1 = require("../src/Stream");
var Option_1 = require("../src/Option");
var assert = require("assert");
function myEq(a, b) {
    if (a === null && b === null) {
        return true;
    }
    if ((a === null) !== (b === null)) {
        return false;
    }
    if (a === undefined && b === undefined) {
        return true;
    }
    if ((a === undefined) !== (b === undefined)) {
        return false;
    }
    if (a.isSome && b.isSome &&
        a.isSome() && b.isSome()) {
        // workaround for Option<array> equality
        // useful in HashMap tests
        return myEq(a.getOrThrow(), b.getOrThrow());
    }
    if (a.toArray) {
        // workaround for the zip test Vector.of([1,"a"]) equality
        // real Vector returns false, compilation error otherwise
        return myEq(a.toArray(), b.toArray());
    }
    if (a.equals) {
        return a.equals(b);
    }
    if (Array.isArray(a)) {
        if (a.length !== b.length) {
            return false;
        }
        for (var i = 0; i < a.length; i++) {
            if (!myEq(a[i], b[i])) {
                return false;
            }
        }
        return true;
    }
    return JSON.stringify(a) === JSON.stringify(b);
}
// adding date support to myEq above isn't enough because I have Option<Date>
// in one of the tests...
Date.prototype.equals = function (other) { return this.getTime() === other.getTime(); };
var randomValues = [0.49884723907769635, 0.3226548779864311];
var randomIndex = 0;
var origMathRandom = Math.random;
var mockMathRandom = function () { return randomValues[(randomIndex++) % randomValues.length]; };
function resetMathRandom() {
    randomIndex = 0;
    Math.random = mockMathRandom;
}
describe("Stream.ts docstrings", function () {
    it("Option", function () {
        resetMathRandom();
        var xvar = Stream_1.Stream.iterate(1, function (x) { return x * 2; }).take(4);
        ;
        assert.ok(myEq(Stream_1.Stream.of(1, 2, 4, 8), xvar), Stream_1.Stream.of(1, 2, 4, 8) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Stream.ts docstrings", function () {
    it("Option", function () {
        resetMathRandom();
        var xvar = Stream_1.Stream.continually(Math.random).take(2);
        ;
        assert.ok(myEq(Stream_1.Stream.of(0.49884723907769635, 0.3226548779864311), xvar), Stream_1.Stream.of(0.49884723907769635, 0.3226548779864311) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Stream.ts docstrings", function () {
    it("isEmpty", function () {
        resetMathRandom();
        var xvar = Vector_1.Vector.of(Stream_1.Stream.of(1), Stream_1.Stream.empty())
            .filter(Stream_1.Stream.isEmpty);
        assert.ok(myEq(Vector_1.Vector.of(Stream_1.Stream.empty()), xvar), Vector_1.Vector.of(Stream_1.Stream.empty()) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Stream.ts docstrings", function () {
    it("isNotEmpty", function () {
        resetMathRandom();
        var xvar = Vector_1.Vector.of(Stream_1.Stream.of(1), Stream_1.Stream.empty())
            .filter(Stream_1.Stream.isNotEmpty)
            .map(function (s) { return s.head().get() + 1; });
        assert.ok(myEq(Vector_1.Vector.of(2), xvar), Vector_1.Vector.of(2) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Stream.ts docstrings", function () {
    it("iterate", function () {
        resetMathRandom();
        var xvar = Stream_1.Stream.iterate(1, function (x) { return x * 2; }).take(4);
        ;
        assert.ok(myEq(Stream_1.Stream.of(1, 2, 4, 8), xvar), Stream_1.Stream.of(1, 2, 4, 8) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Stream.ts docstrings", function () {
    it("continually", function () {
        resetMathRandom();
        var xvar = Stream_1.Stream.continually(function () { return 1; }).take(4);
        ;
        assert.ok(myEq(Stream_1.Stream.of(1, 1, 1, 1), xvar), Stream_1.Stream.of(1, 1, 1, 1) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Stream.ts docstrings", function () {
    it("continually", function () {
        resetMathRandom();
        var xvar = Stream_1.Stream.continually(Math.random).take(2);
        ;
        assert.ok(myEq(Stream_1.Stream.of(0.49884723907769635, 0.3226548779864311), xvar), Stream_1.Stream.of(0.49884723907769635, 0.3226548779864311) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Stream.ts docstrings", function () {
    it("unfoldRight", function () {
        resetMathRandom();
        var xvar = Stream_1.Stream.unfoldRight(10, function (x) { return Option_1.Option.of(x)
            .filter(function (x) { return x !== 0; })
            .map(function (x) { return [x, x - 1]; }); });
        ;
        assert.ok(myEq(Stream_1.Stream.of(10, 9, 8, 7, 6, 5, 4, 3, 2, 1), xvar), Stream_1.Stream.of(10, 9, 8, 7, 6, 5, 4, 3, 2, 1) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Stream.ts docstrings", function () {
    it("fold", function () {
        resetMathRandom();
        var xvar = Stream_1.Stream.of(1, 2, 3).fold(0, function (a, b) { return a + b; });
        ;
        assert.ok(myEq(6, xvar), 6 + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Stream.ts docstrings", function () {
    it("foldLeft", function () {
        resetMathRandom();
        var xvar = Vector_1.Vector.of("a", "b", "c").foldLeft("!", function (xs, x) { return x + xs; });
        ;
        assert.ok(myEq("cba!", xvar), "cba!" + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Stream.ts docstrings", function () {
    it("foldRight", function () {
        resetMathRandom();
        var xvar = Vector_1.Vector.of("a", "b", "c").foldRight("!", function (x, xs) { return xs + x; });
        ;
        assert.ok(myEq("!cba", xvar), "!cba" + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Stream.ts docstrings", function () {
    it("zip", function () {
        resetMathRandom();
        var xvar = Vector_1.Vector.of(1, 2, 3).zip(["a", "b", "c"]);
        assert.ok(myEq(Vector_1.Vector.of([1, "a"], [2, "b"], [3, "c"]), xvar), Vector_1.Vector.of([1, "a"], [2, "b"], [3, "c"]) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Stream.ts docstrings", function () {
    it("zipWithIndex", function () {
        resetMathRandom();
        var xvar = Stream_1.Stream.of("a", "b").zipWithIndex().map(function (_a) {
            var v = _a[0], idx = _a[1];
            return v + idx;
        });
        ;
        assert.ok(myEq(Stream_1.Stream.of("a0", "b1"), xvar), Stream_1.Stream.of("a0", "b1") + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Stream.ts docstrings", function () {
    it("reverse", function () {
        resetMathRandom();
        var xvar = Stream_1.Stream.of(1, 2, 3).reverse();
        ;
        assert.ok(myEq(Stream_1.Stream.of(3, 2, 1), xvar), Stream_1.Stream.of(3, 2, 1) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Stream.ts docstrings", function () {
    it("span", function () {
        resetMathRandom();
        var xvar = Stream_1.Stream.of(1, 2, 3, 4, 5, 6).span(function (x) { return x < 3; });
        assert.ok(myEq([Stream_1.Stream.of(1, 2), Stream_1.Stream.of(3, 4, 5, 6)], xvar), [Stream_1.Stream.of(1, 2), Stream_1.Stream.of(3, 4, 5, 6)] + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Stream.ts docstrings", function () {
    it("splitAt", function () {
        resetMathRandom();
        var xvar = Stream_1.Stream.of(1, 2, 3, 4, 5).splitAt(3);
        assert.ok(myEq([Stream_1.Stream.of(1, 2, 3), Stream_1.Stream.of(4, 5)], xvar), [Stream_1.Stream.of(1, 2, 3), Stream_1.Stream.of(4, 5)] + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Stream.ts docstrings", function () {
    it("partition", function () {
        resetMathRandom();
        var xvar = Stream_1.Stream.of(1, 2, 3, 4).partition(function (x) { return x % 2 === 0; });
        assert.ok(myEq([Stream_1.Stream.of(2, 4), Stream_1.Stream.of(1, 3)], xvar), [Stream_1.Stream.of(2, 4), Stream_1.Stream.of(1, 3)] + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Stream.ts docstrings", function () {
    it("cycle", function () {
        resetMathRandom();
        var xvar = Stream_1.Stream.of(1, 2, 3).cycle().take(8);
        assert.ok(myEq(Stream_1.Stream.of(1, 2, 3, 1, 2, 3, 1, 2), xvar), Stream_1.Stream.of(1, 2, 3, 1, 2, 3, 1, 2) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Stream.ts docstrings", function () {
    it("mapOption", function () {
        resetMathRandom();
        var xvar = Stream_1.Stream.of(1, 2, 6).mapOption(function (x) { return x % 2 === 0 ?
            Option_1.Option.of(x + 1) : Option_1.Option.none(); });
        assert.ok(myEq(Stream_1.Stream.of(3, 7), xvar), Stream_1.Stream.of(3, 7) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Stream.ts docstrings", function () {
    it("sortBy", function () {
        resetMathRandom();
        var activityOrder = ["Writer", "Actor", "Director"];
        var xvar = Stream_1.Stream.of({ name: "George", activity: "Director" }, { name: "Robert", activity: "Actor" })
            .sortBy(function (p1, p2) { return activityOrder.indexOf(p1.activity) - activityOrder.indexOf(p2.activity); });
        ;
        assert.ok(myEq(Stream_1.Stream.of({ "name": "Robert", "activity": "Actor" }, { "name": "George", "activity": "Director" }), xvar), Stream_1.Stream.of({ "name": "Robert", "activity": "Actor" }, { "name": "George", "activity": "Director" }) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Stream.ts docstrings", function () {
    it("sortOn", function () {
        resetMathRandom();
        var xvar = Stream_1.Stream.of({ a: 3, b: "b" }, { a: 1, b: "test" }, { a: 2, b: "a" }).sortOn(function (elt) { return elt.a; });
        assert.ok(myEq(Stream_1.Stream.of({ a: 1, b: "test" }, { a: 2, b: "a" }, { a: 3, b: "b" }), xvar), Stream_1.Stream.of({ a: 1, b: "test" }, { a: 2, b: "a" }, { a: 3, b: "b" }) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Stream.ts docstrings", function () {
    it("sortOn", function () {
        resetMathRandom();
        var xvar = Stream_1.Stream.of({ a: 1, b: "b" }, { a: 1, b: "test" }, { a: 2, b: "a" }).sortOn(function (elt) { return elt.a; }, { desc: function (elt) { return elt.b; } });
        assert.ok(myEq(Stream_1.Stream.of({ a: 1, b: "test" }, { a: 1, b: "b" }, { a: 2, b: "a" }), xvar), Stream_1.Stream.of({ a: 1, b: "test" }, { a: 1, b: "b" }, { a: 2, b: "a" }) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Stream.ts docstrings", function () {
    it("distinctBy", function () {
        resetMathRandom();
        var xvar = Stream_1.Stream.of(1, 1, 2, 3, 2, 3, 1).distinctBy(function (x) { return x; });
        ;
        assert.ok(myEq(Stream_1.Stream.of(1, 2, 3), xvar), Stream_1.Stream.of(1, 2, 3) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Stream.ts docstrings", function () {
    it("sliding", function () {
        resetMathRandom();
        var xvar = Stream_1.Stream.of(1, 2, 3, 4, 5, 6, 7, 8).sliding(3);
        assert.ok(myEq(Stream_1.Stream.of(Stream_1.Stream.of(1, 2, 3), Stream_1.Stream.of(4, 5, 6), Stream_1.Stream.of(7, 8)), xvar), Stream_1.Stream.of(Stream_1.Stream.of(1, 2, 3), Stream_1.Stream.of(4, 5, 6), Stream_1.Stream.of(7, 8)) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Stream.ts docstrings", function () {
    it("scanLeft", function () {
        resetMathRandom();
        var xvar = Stream_1.Stream.of(1, 2, 3).scanLeft(0, function (soFar, cur) { return soFar + cur; });
        assert.ok(myEq(Stream_1.Stream.of(0, 1, 3, 6), xvar), Stream_1.Stream.of(0, 1, 3, 6) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Stream.ts docstrings", function () {
    it("scanRight", function () {
        resetMathRandom();
        var xvar = Stream_1.Stream.of(1, 2, 3).scanRight(0, function (cur, soFar) { return soFar + cur; });
        assert.ok(myEq(Stream_1.Stream.of(6, 5, 3, 0), xvar), Stream_1.Stream.of(6, 5, 3, 0) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Stream.ts docstrings", function () {
    it("mkString", function () {
        resetMathRandom();
        var xvar = Vector_1.Vector.of(1, 2, 3).mkString(", ");
        assert.ok(myEq("1, 2, 3", xvar), "1, 2, 3" + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Stream.ts docstrings", function () {
    it("toMap", function () {
        resetMathRandom();
        var xvar = Stream_1.Stream.of(1, 2, 3).toMap(function (x) { return [x.toString(), x]; });
        assert.ok(myEq(HashMap_1.HashMap.of(["1", 1], ["2", 2], ["3", 3]), xvar), HashMap_1.HashMap.of(["1", 1], ["2", 2], ["3", 3]) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Stream.ts docstrings", function () {
    it("toSet", function () {
        resetMathRandom();
        var xvar = Stream_1.Stream.of(1, 2, 3, 3, 4).toSet(function (x) { return x; });
        assert.ok(myEq(HashSet_1.HashSet.of(1, 2, 3, 4), xvar), HashSet_1.HashSet.of(1, 2, 3, 4) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Stream.ts docstrings", function () {
    it("fold", function () {
        resetMathRandom();
        var xvar = Stream_1.Stream.of(1, 2, 3).fold(0, function (a, b) { return a + b; });
        ;
        assert.ok(myEq(6, xvar), 6 + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Stream.ts docstrings", function () {
    it("foldLeft", function () {
        resetMathRandom();
        var xvar = Vector_1.Vector.of("a", "b", "c").foldLeft("!", function (xs, x) { return x + xs; });
        ;
        assert.ok(myEq("cba!", xvar), "cba!" + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Stream.ts docstrings", function () {
    it("foldRight", function () {
        resetMathRandom();
        var xvar = Vector_1.Vector.of("a", "b", "c").foldRight("!", function (x, xs) { return xs + x; });
        ;
        assert.ok(myEq("!cba", xvar), "!cba" + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Stream.ts docstrings", function () {
    it("zip", function () {
        resetMathRandom();
        var xvar = Vector_1.Vector.of(1, 2, 3).zip(["a", "b", "c"]);
        assert.ok(myEq(Vector_1.Vector.of([1, "a"], [2, "b"], [3, "c"]), xvar), Vector_1.Vector.of([1, "a"], [2, "b"], [3, "c"]) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Stream.ts docstrings", function () {
    it("zipWithIndex", function () {
        resetMathRandom();
        var xvar = Stream_1.Stream.of("a", "b").zipWithIndex().map(function (_a) {
            var v = _a[0], idx = _a[1];
            return v + idx;
        });
        ;
        assert.ok(myEq(Stream_1.Stream.of("a0", "b1"), xvar), Stream_1.Stream.of("a0", "b1") + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Stream.ts docstrings", function () {
    it("reverse", function () {
        resetMathRandom();
        var xvar = Stream_1.Stream.of(1, 2, 3).reverse();
        ;
        assert.ok(myEq(Stream_1.Stream.of(3, 2, 1), xvar), Stream_1.Stream.of(3, 2, 1) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Stream.ts docstrings", function () {
    it("span", function () {
        resetMathRandom();
        var xvar = Stream_1.Stream.of(1, 2, 3, 4, 5, 6).span(function (x) { return x < 3; });
        assert.ok(myEq([Stream_1.Stream.of(1, 2), Stream_1.Stream.of(3, 4, 5, 6)], xvar), [Stream_1.Stream.of(1, 2), Stream_1.Stream.of(3, 4, 5, 6)] + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Stream.ts docstrings", function () {
    it("splitAt", function () {
        resetMathRandom();
        var xvar = Stream_1.Stream.of(1, 2, 3, 4, 5).splitAt(3);
        assert.ok(myEq([Stream_1.Stream.of(1, 2, 3), Stream_1.Stream.of(4, 5)], xvar), [Stream_1.Stream.of(1, 2, 3), Stream_1.Stream.of(4, 5)] + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Stream.ts docstrings", function () {
    it("partition", function () {
        resetMathRandom();
        var xvar = Stream_1.Stream.of(1, 2, 3, 4).partition(function (x) { return x % 2 === 0; });
        assert.ok(myEq([Stream_1.Stream.of(2, 4), Stream_1.Stream.of(1, 3)], xvar), [Stream_1.Stream.of(2, 4), Stream_1.Stream.of(1, 3)] + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Stream.ts docstrings", function () {
    it("cycle", function () {
        resetMathRandom();
        var xvar = Stream_1.Stream.of(1, 2, 3).cycle().take(8);
        assert.ok(myEq(Stream_1.Stream.of(1, 2, 3, 1, 2, 3, 1, 2), xvar), Stream_1.Stream.of(1, 2, 3, 1, 2, 3, 1, 2) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Stream.ts docstrings", function () {
    it("mapOption", function () {
        resetMathRandom();
        var xvar = Stream_1.Stream.of(1, 2, 6).mapOption(function (x) { return x % 2 === 0 ?
            Option_1.Option.of(x + 1) : Option_1.Option.none(); });
        assert.ok(myEq(Stream_1.Stream.of(3, 7), xvar), Stream_1.Stream.of(3, 7) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Stream.ts docstrings", function () {
    it("sortBy", function () {
        resetMathRandom();
        var activityOrder = ["Writer", "Actor", "Director"];
        var xvar = Stream_1.Stream.of({ name: "George", activity: "Director" }, { name: "Robert", activity: "Actor" })
            .sortBy(function (p1, p2) { return activityOrder.indexOf(p1.activity) - activityOrder.indexOf(p2.activity); });
        ;
        assert.ok(myEq(Stream_1.Stream.of({ "name": "Robert", "activity": "Actor" }, { "name": "George", "activity": "Director" }), xvar), Stream_1.Stream.of({ "name": "Robert", "activity": "Actor" }, { "name": "George", "activity": "Director" }) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Stream.ts docstrings", function () {
    it("sortOn", function () {
        resetMathRandom();
        var xvar = Stream_1.Stream.of({ a: 3, b: "b" }, { a: 1, b: "test" }, { a: 2, b: "a" }).sortOn(function (elt) { return elt.a; });
        assert.ok(myEq(Stream_1.Stream.of({ a: 1, b: "test" }, { a: 2, b: "a" }, { a: 3, b: "b" }), xvar), Stream_1.Stream.of({ a: 1, b: "test" }, { a: 2, b: "a" }, { a: 3, b: "b" }) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Stream.ts docstrings", function () {
    it("sortOn", function () {
        resetMathRandom();
        var xvar = Stream_1.Stream.of({ a: 1, b: "b" }, { a: 1, b: "test" }, { a: 2, b: "a" }).sortOn(function (elt) { return elt.a; }, { desc: function (elt) { return elt.b; } });
        assert.ok(myEq(Stream_1.Stream.of({ a: 1, b: "test" }, { a: 1, b: "b" }, { a: 2, b: "a" }), xvar), Stream_1.Stream.of({ a: 1, b: "test" }, { a: 1, b: "b" }, { a: 2, b: "a" }) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Stream.ts docstrings", function () {
    it("distinctBy", function () {
        resetMathRandom();
        var xvar = Stream_1.Stream.of(1, 1, 2, 3, 2, 3, 1).distinctBy(function (x) { return x; });
        ;
        assert.ok(myEq(Stream_1.Stream.of(1, 2, 3), xvar), Stream_1.Stream.of(1, 2, 3) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Stream.ts docstrings", function () {
    it("sliding", function () {
        resetMathRandom();
        var xvar = Stream_1.Stream.of(1, 2, 3, 4, 5, 6, 7, 8).sliding(3);
        assert.ok(myEq(Stream_1.Stream.of(Stream_1.Stream.of(1, 2, 3), Stream_1.Stream.of(4, 5, 6), Stream_1.Stream.of(7, 8)), xvar), Stream_1.Stream.of(Stream_1.Stream.of(1, 2, 3), Stream_1.Stream.of(4, 5, 6), Stream_1.Stream.of(7, 8)) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Stream.ts docstrings", function () {
    it("scanLeft", function () {
        resetMathRandom();
        var xvar = Stream_1.Stream.of(1, 2, 3).scanLeft(0, function (soFar, cur) { return soFar + cur; });
        assert.ok(myEq(Stream_1.Stream.of(0, 1, 3, 6), xvar), Stream_1.Stream.of(0, 1, 3, 6) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Stream.ts docstrings", function () {
    it("scanRight", function () {
        resetMathRandom();
        var xvar = Stream_1.Stream.of(1, 2, 3).scanRight(0, function (cur, soFar) { return soFar + cur; });
        assert.ok(myEq(Stream_1.Stream.of(6, 5, 3, 0), xvar), Stream_1.Stream.of(6, 5, 3, 0) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Stream.ts docstrings", function () {
    it("mkString", function () {
        resetMathRandom();
        var xvar = Vector_1.Vector.of(1, 2, 3).mkString(", ");
        assert.ok(myEq("1, 2, 3", xvar), "1, 2, 3" + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Stream.ts docstrings", function () {
    it("toMap", function () {
        resetMathRandom();
        var xvar = Stream_1.Stream.of(1, 2, 3).toMap(function (x) { return [x.toString(), x]; });
        assert.ok(myEq(HashMap_1.HashMap.of(["1", 1], ["2", 2], ["3", 3]), xvar), HashMap_1.HashMap.of(["1", 1], ["2", 2], ["3", 3]) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
describe("Stream.ts docstrings", function () {
    it("toSet", function () {
        resetMathRandom();
        var xvar = Stream_1.Stream.of(1, 2, 3, 3, 4).toSet(function (x) { return x; });
        assert.ok(myEq(HashSet_1.HashSet.of(1, 2, 3, 4), xvar), HashSet_1.HashSet.of(1, 2, 3, 4) + " !== " + xvar);
        Math.random = origMathRandom;
    });
});
//# sourceMappingURL=apidoc-Stream.js.map